package bundle_test

import (
	"os"
	"testing"

	"git.badhouseplants.net/allanger/shoebill/pkg/types/bundle"
	"git.badhouseplants.net/allanger/shoebill/utils/helpers"
	"github.com/stretchr/testify/assert"
)

// Test that the file can be read
func TestUnitReadValidFile(t *testing.T) {
	f := helpers.CreateFile(t)
	defer os.Remove(f.Name())

	const validFile = `---
metadata:
  name: db-operator
  version: 1.0.0
  maintainer:
    name: allanger
    email: allanger@badhouseplants.net
    website: https://badhouseplants.net
`
	helpers.FillFile(t, f, validFile)

	bundle, err := bundle.ReadFromFile(f.Name())

	// Check that there is no unexpected error
	assert.NoError(t, err)

	// Check the bundle metadata
	assert.Equal(t, "1.0.0", bundle.Metadata.Version)
	assert.Equal(t, "db-operator", bundle.Metadata.Name)

	assert.Equal(t, "allanger", bundle.Metadata.Maintainer.Name)
	assert.Equal(t, "allanger@badhouseplants.net", bundle.Metadata.Maintainer.Email)
	assert.Equal(t, "https://badhouseplants.net", bundle.Metadata.Maintainer.Website)
}

func TestIntegrationBootstrap(t *testing.T) {
	bundlePath := "../../../test/test-bundle/bundle.yaml"
	bundle, err := bundle.ReadFromFile(bundlePath)

	// Check that there is no unexpected error
	assert.NoError(t, err)

	// Check the bundle file in the test folder to get the actual data
	assert.Equal(t, "0.0.1", bundle.Metadata.Version)
	assert.Equal(t, "test-bundle", bundle.Metadata.Name)

	assert.Equal(t, "allanger", bundle.Metadata.Maintainer.Name)
	assert.Equal(t, "allanger@badhouseplants.net", bundle.Metadata.Maintainer.Email)
	assert.Equal(t, "https://badhouseplants.net", bundle.Metadata.Maintainer.Website)

	err = bundle.Bootstrap()
	assert.NoError(t, err)

	assert.Equal(t, "Deployment", bundle.Workload.Kind)
	assert.Equal(t, 1, bundle.Workload.Replicas)
}
